@@ -1,10 +1,19 @@
 /*
- ============================================================================
- Name        : hashset.h
- Author      : martin.dvorak@mindforger.com
- Copyright   : Apache 2.0
- Description : Hash set
- ============================================================================
+ hashset.h      header file for hash set
+
+ Copyright (C) 2014  Martin Dvorak <martin.dvorak@mindforger.com>
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
 */
 
 #ifndef _HASHSET_H_
