@@ -1,15 +1,25 @@
 /*
- ============================================================================
- Name        : radixsort.h
- Author      : martin.dvorak@mindforger.com
- Copyright   : Apache 2.0
- Description : Radix sort
- ============================================================================
+ radixsort.h        header file for radix sort implementation
+
+ Copyright (C) 2014  Martin Dvorak <martin.dvorak@mindforger.com>
+
+ Licensed under the Apache License, Version 2.0 (the "License");
+ you may not use this file except in compliance with the License.
+ You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+ Unless required by applicable law or agreed to in writing, software
+ distributed under the License is distributed on an "AS IS" BASIS,
+ WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ See the License for the specific language governing permissions and
+ limitations under the License.
 */
 
 #ifndef RADIXSORT_H_
 #define RADIXSORT_H_
 
+#include <stdbool.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <math.h>
@@ -19,6 +29,10 @@
 
 #define RADIX_SLOT_SIZE 1000
 
+#define RADIX_BIG_KEYS_SKIP     0
+#define RADIX_BIG_KEYS_FLOOR    1
+#define RADIX_BIG_KEYS_EXIT     2
+
 #define RADIX_DEBUG_LEVEL_NONE  0
 #define RADIX_DEBUG_LEVEL_WARN  1
 #define RADIX_DEBUG_LEVEL_DEBUG 2
@@ -41,8 +55,7 @@ typedef struct {
     unsigned keyLimit;
     RadixItem ***topDigits;
 
-    bool optFloorAndInsertBigKeys;
-    bool optIgnoreBigKeys;
+    int optionBigKeys;
 
     RadixSlot **_slotDescriptors;
     unsigned _slotsCount;
